summaryrefslogtreecommitdiff
path: root/src/cargotype.cpp
diff options
context:
space:
mode:
authorrubidium <rubidium@openttd.org>2011-12-15 21:56:00 +0000
committerrubidium <rubidium@openttd.org>2011-12-15 21:56:00 +0000
commit3d88c74389ec978bb198415816364898963bb979 (patch)
tree828173a0f2926b9082ff0ec1a08a293b213defba /src/cargotype.cpp
parentdf0afdf0dca6b3d4f621248ada2aed73d7481c66 (diff)
downloadopenttd-3d88c74389ec978bb198415816364898963bb979.tar.xz
(svn r23526) -Codechange: unify cargos vs cargoes
Diffstat (limited to 'src/cargotype.cpp')
-rw-r--r--src/cargotype.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/cargotype.cpp b/src/cargotype.cpp
index 82836b324..fb6583f2b 100644
--- a/src/cargotype.cpp
+++ b/src/cargotype.cpp
@@ -7,7 +7,7 @@
* See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
*/
/** @file cargotype.cpp Implementation of cargos. */
#include "stdafx.h"
#include "cargotype.h"
@@ -122,7 +122,7 @@ SpriteID CargoSpec::GetCargoIcon() const
}
const CargoSpec *_sorted_cargo_specs[NUM_CARGO]; ///< Cargo specifications sorted alphabetically by name.
-uint8 _sorted_cargo_specs_size; ///< Number of cargo specifications stored at the _sorted_cargo_specs array (including special cargos).
+uint8 _sorted_cargo_specs_size; ///< Number of cargo specifications stored at the _sorted_cargo_specs array (including special cargoes).
uint8 _sorted_standard_cargo_specs_size; ///< Number of standard cargo specifications stored at the _sorted_cargo_specs array.
@@ -7,7 +7,7 @@
* See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
*/
-/** @file cargotype.cpp Implementation of cargos. */
+/** @file cargotype.cpp Implementation of cargoes. */
#include "stdafx.h"
#include "cargotype.h"